==> revscoring-1.3.2.tar.gz: revscoring-1.3.2/revscoring/languages/__init__.py <==
"""
This module implements a set of languages as collections of features that are
language specific.

feature collections
+++++++++++++++++++
Languages implement a subset of feature collections (e.g.
:class:`~revscoring.languages.features.Dictionary`,
:class:`~revscoring.languages.features.Stopwords`,
:class:`~revscoring.languages.features.Stemmed` and
:class:`~revscoring.languages.features.RegexMatches`) based on what
language assets are available. See :mod:`revscoring.languages.features`.

dutch
+++++
.. automodule:: revscoring.languages.arabic
    :members:

dutch
+++++
.. automodule:: revscoring.languages.dutch
    :members:

english
+++++++
.. automodule:: revscoring.languages.english
    :members:

estonian
++++++++
.. automodule:: revscoring.languages.estonian
    :members:

french
++++++
.. automodule:: revscoring.languages.french
    :members:

german
++++++
.. automodule:: revscoring.languages.german
    :members:

hebrew
++++++
.. automodule:: revscoring.languages.hebrew
    :members:

indonesian
++++++++++
.. automodule:: revscoring.languages.indonesian
    :members:

italian
+++++++
.. automodule:: revscoring.languages.italian
    :members:

japanese
+++++++
.. automodule:: revscoring.languages.japanese
    :members:

persian
+++++++
.. automodule:: revscoring.languages.persian
    :members:

portuguese
++++++++++
.. automodule:: revscoring.languages.portuguese
    :members:

spanish
+++++++
.. automodule:: revscoring.languages.spanish
    :members:

turkish
+++++++
.. automodule:: revscoring.languages.turkish
    :members:

ukrainian
+++++++++
.. automodule:: revscoring.languages.ukrainian
    :members:

vietnamese
++++++++++
.. automodule:: revscoring.languages.vietnamese
    :members:

"""

==> revscoring-2.4.0.tar.gz: revscoring-2.4.0/revscoring/languages/__init__.py <==
"""
This module implements a set of languages as collections of features that are
language specific.

feature collections
+++++++++++++++++++
Languages implement a subset of feature collections (e.g.
:class:`~revscoring.languages.features.Dictionary`,
:class:`~revscoring.languages.features.Stopwords`,
:class:`~revscoring.languages.features.Stemmed` and
:class:`~revscoring.languages.features.RegexMatches`) based on what
language assets are available. See :mod:`revscoring.languages.features`.

albanian
++++++++
.. automodule:: revscoring.languages.albanian
    :members:

arabic
++++++
.. automodule:: revscoring.languages.arabic
    :members:

bengali
+++++++
.. automodule:: revscoring.languages.bengali
    :members:

bosnian
+++++
.. automodule:: revscoring.languages.bosnian
    :members:

catalan
+++++
.. automodule:: revscoring.languages.catalan
    :members:

chinese
+++++++
.. automodule:: revscoring.languages.chinese
    :members:

croatian
+++++
.. automodule:: revscoring.languages.croatian
    :members:

czech
+++++
.. automodule:: revscoring.languages.czech
    :members:

dutch
+++++
.. automodule:: revscoring.languages.dutch
    :members:

english
+++++++
.. automodule:: revscoring.languages.english
    :members:

estonian
++++++++
.. automodule:: revscoring.languages.estonian
    :members:

finnishswedish

french
++++++
.. automodule:: revscoring.languages.french
    :members:

galician
++++++
.. automodule:: revscoring.languages.galician
    :members:

german
++++++
.. automodule:: revscoring.languages.german
    :members:

greek
+++++++
.. automodule:: revscoring.languages.greek
    :members:

hebrew
++++++
.. automodule:: revscoring.languages.hebrew
    :members:

hindi
+++++
.. automodule:: revscoring.languages.hindi
    :members:

hungarian
+++++++++
.. automodule:: revscoring.languages.hungarian
    :members:

indonesian
++++++++++
.. automodule:: revscoring.languages.indonesian
    :members:

italian
+++++++
.. automodule:: revscoring.languages.italian
    :members:

japanese
++++++++
.. automodule:: revscoring.languages.japanese
    :members:

korean
++++++
.. automodule:: revscoring.languages.korean
    :members:

latvian
++++++
.. automodule:: revscoring.languages.latvian
    :members:

norwegian
+++++++++
.. automodule:: revscoring.languages.norwegian
    :members:

persian
+++++++
.. automodule:: revscoring.languages.persian
    :members:

portuguese
++++++++++
.. automodule:: revscoring.languages.portuguese
    :members:

romanian
++++++++
.. automodule:: revscoring.languages.romanian
    :members:

spanish
+++++++
.. automodule:: revscoring.languages.spanish
    :members:

swedish
+++++++
.. automodule:: revscoring.languages.swedish
    :members:

tamil
+++++
.. automodule:: revscoring.languages.tamil
    :members:

turkish
+++++++
.. automodule:: revscoring.languages.turkish
    :members:

ukrainian
+++++++++
.. automodule:: revscoring.languages.ukrainian
    :members:

vietnamese
++++++++++
.. automodule:: revscoring.languages.vietnamese
    :members:

"""
